'''
Python RPCLayout for make more easier your code.
By: neokeee & etherlesss
'''

from .RPCLayout import RPCLayout

__title__ = "RPCLayout"
__author__ = "neokeee"
__copyright__ = "Copyright 2022 neokeee"
__license__ = 'MIT'
__version__ = '2.1.3'